#
# spec file for package aardvark-dns
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aardvark-dns
Version:        1.12.2
Release:        1.1
Summary:        Authoritative dns server for A/AAAA container records
License:        Apache-2.0
URL:            https://github.com/containers/%{name}
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  cargo-packaging
BuildRequires:  rust+cargo >= 1.70
# Disable this line if you wish to support all platforms.

%description
Aardvark-dns is an authoritative dns server for A/AAAA container records.
It can forward other requests to configured resolvers.

%prep
%autosetup -a1

%build
%make_build

%install
%make_install DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBEXECDIR=%{_libexecdir}

%files
%license LICENSE
%dir %{_libexecdir}/podman
%{_libexecdir}/podman/%{name}

%changelog
* Wed Sep  4 2024 dcermak@suse.com
- Update to version 1.12.2:
  * Release v1.12.2
  * Update release notes for 1.12.2
  * coredns: work on tcp requests concurrently
  * tcp: add timeout to connection (fixes bsc#1230153 / CVE-2024-8418)
  * cirrus: update branch names
* Wed Aug  7 2024 danish.prakash@suse.com
- Update to version 1.12.1:
  * Release v1.12.1
  * Updated release notes for 1.12.1
  * Change av cargo categories
  * Bump to 1.13.0-dev
  * Release 1.12.0
  * Release notes for 1.12
  * config: ignore enoent errors while reading configs
  * run cargo update
  * update upsteam resolvers on each refresh
  * fix(deps): update rust crate syslog to v7
  * fix(deps): update rust crate tokio to 1.39.2
  * add tcp support for forwarding
  * add tcp listening support
  * test: add new test to check for startup error
  * return bind error to caller on first start
  * add our own error type and use it over anyhow
  * server: use anyhow to wrap parse_configs error
  * server: split out main loop into new function
  * main: remove aardvark-dns error prefix
  * coredns: remove unnecessary try_join! call
  * coredns: drop pointless name var
  * serve: read nameservers once
  * replace signal-hook with tokio::signal
  * serve: fix broken error logging
  * server: improve parent <-> child error handling
  * add some basic perf check script
  * fix(deps): update rust crate tokio to 1.39.0
  * coredns: create reply_ip() function
  * coredns: match dns type explicitly
  * server: use only one tokio runtime
  * coredns: improve indentation for process_message()
  * coredns: move upstream resolvers detection later
  * coredns: do not clone sender
  * read AARDVARK_NO_PROXY once
  * coredns: move main code out of select!
  * coredns: fix "name" naming
  * coredns: remove unused forward_addr/port
  * coredns: fix handling of dns search domain
  * coredns: rework PTR lookup flow
  * fix(deps): update rust crate tokio to 1.38.1
  * [skip-ci] TMT: Reorg upstream tests for downstream reusability
  * [skip-ci] Packit: use `packages: [aardvark-dns-fedora]` for podman-next builds
  * Be sure to have at least Epoch 2 to preserve upgrade path in c10s.
  * fix(deps): update rust crate log to 0.4.22
  * [CI:BUILD] rpm: Update Rust macro usage
  * fix(deps): update rust crate tokio to 1.38.0
  * Bump to 1.12.0-dev
* Fri Jul 26 2024 Danish Prakash <danish.prakash@suse.com>
- rust >= 1.70 is required to build more recent versions of this
  package. Also, BuildRequire cargo+rust to prevent conflicts with
  `cargo-packaging`.
* Mon Jun  3 2024 danish.prakash@suse.com
- Remove redundant source: cargo_config
- Update to version 1.11.0:
  * Release v1.11.0
  * v1.11.0 release notes
  * run cargo update
  * chore(deps): update dependency containers/automation_images to v20240529
  * Internal networks cannot make external DNS requests
  * fix(deps): update rust crate anyhow to 1.0.86
  * fix(deps): update rust crate nix to 0.29.0
  * [skip-ci] RPM: use default __cargo macro across all envs
  * chore(deps): update dependency containers/automation_images to v20240513
  * fix(deps): update rust crate anyhow to 1.0.83
  * [skip-ci] Packit: separate `packages` key for rhel jobs
  * fix(deps): update rust crate libc to 0.2.154
  * [skip-ci] Packit: enable rhel10, c10s tests and c10s downstream sync
  * [skip-ci] Packit: Remove EL8 jobs
  * fix(deps): update rust crate syslog to ^6.1.1
  * fix reverse ipv6 lookup test flake
  * fix(deps): update hickory-dns monorepo to 0.24.1
  * chore(deps): update rust crate chrono to 0.4.38
  * Don't tear down all server threads on SIGHUP (bsc#1224167)
  * fix(deps): update rust crate anyhow to 1.0.82
  * fix(deps): update rust crate tokio to 1.37.0
  * Update to nix-0.28.0
  * update chrono package
  * chore(deps): update dependency containers/automation_images to v20240320
  * fix(deps): update rust crate anyhow to 1.0.81
  * tests: check queried domain name in reverse lookup tests
  * fix: set name for answers in reverse lookups
  * chore: fix typo in runner script
  * chore: fix log message when doing reverse lookup
  * fix(deps): update rust crate log to 0.4.21
  * fix(deps): update rust crate anyhow to 1.0.80
  * chore(deps): update rust crate chrono to 0.4.34
  * fix(deps): update rust crate async-broadcast to 0.7.0
  * fix(deps): update rust crate tokio to 1.36.0
  * [CI:DOCS] Packit: disable bodhi tasks
  * chore(deps): update rust crate chrono to 0.4.33
  * Bump to 1.11.0-dev
* Thu Jan 25 2024 danish.prakash@suse.com
- Update to version 1.10.0:
  * Release 1.10.0
  * Release notes for 1.10.0
  * chore(deps): update rust crate chrono to 0.4.32
  * chore(deps): update dependency containers/automation_images to v20240102
  * fix(deps): update rust crate futures-util to 0.3.30
  * fix(deps): update rust crate anyhow to 1.0.79
  * fix(deps): update rust crate tokio to 1.35.1
  * chore(deps): update dependency containers/automation_images to v20231208
  * fix(deps): update rust crate tokio to 1.35.0
  * fix duplicated IP CI flake
  * server: remove unused kill switch
  * fix(deps): update rust crate clap to ~4.4.10
  * Bump working version to v1.10.0-dev
* Thu Nov 30 2023 danish.prakash@suse.com
- Update to version 1.9.0:
  * Release v1.9.0
  * v1.9.0 Update release notes
  * run cargo update
  * chore(deps): update dependency containers/automation_images to v20231116
  * fix(deps): update rust crate tokio to 1.34.0
  * fix(deps): update rust crate async-broadcast to 0.6.0
  * update trust-dns to hickory
  * fix(deps): update rust crate futures-util to 0.3.29
  * fix(deps): update rust crate trust-dns-server to 0.23.2
  * fix(deps): update rust crate trust-dns-proto to 0.23.2
  * tmt: initial enablement
  * aardvark main: change error reporting
  * chore(deps): update dependency containers/automation_images to v20231004
  * fix(deps): update rust crate trust-dns-proto to 0.23.1
  * fix(deps): update rust crate trust-dns-client to 0.23.1
  * clippy: some format fixes
  * fix(deps): update rust crate tokio to 1.33.0
  * Bump to v1.9.0-dev
* Thu Sep 28 2023 danish.prakash@suse.com
- Update to version 1.8.0:
  * Release v1.8.0
  * update release notes for v1.8.0
  * run cargo update
  * Packit: switch to @containers/packit-build team for copr failure notification comments
  * [CI:BUILD] Packit: tag @lsm5 on copr build failures
  * chore(deps): update rust crate chrono to 0.4.31
  * cargo: bump chrono to 0.4.30
  * test: IPv6 format is changed in v1.72.0
  * bump nix to 0.27.1
  * vendor: bump trust_dns_proto and trust_dns_client to 0.23.0
  * fix(deps): update rust crate trust-dns-server to 0.23.0
  * [CI:BUILD] rpm: spdx compatible license field
  * fix(deps): update rust crate anyhow to 1.0.75
  * fix(deps): update rust crate tokio to 1.32.0
  * chore(deps): update dependency containers/automation_images to v20230816
  * fix(deps): update rust crate tokio to 1.31.0
  * fix(deps): update rust crate anyhow to 1.0.74
  * fix(deps): update rust crate anyhow to 1.0.73
  * fix(deps): update rust crate log to 0.4.20
  * chore(deps): update dependency containers/automation_images to v20230809
  * fix(deps): update rust crate tokio to 1.30.0
  * fix(deps): update rust crate clap to 4.3.21
  * packit: Build PRs into default packit COPRs
  * chore(deps): update dependency containers/automation_images to v20230807
  * fix(deps): update rust crate anyhow to 1.0.72
  * fix(deps): update rust crate signal-hook to 0.3.17
  * fix(deps): update rust crate clap to 4.3.19
  * fix(deps): update rust crate clap to 4.3.15
  * fix(deps): update rust crate signal-hook to 0.3.16
  * [CI:BUILD] Packit: remove pre-sync action
  * fix(deps): update rust crate clap to 4.3.11
  * fix(deps): update rust crate tokio to 1.29.1
  * fix(deps): update rust crate clap to 4.3.10
  * [CI:BUILD] RPM: cleanup spec and fix eln builds
  * bump to v1.8.0-devel
* Tue Jul 11 2023 Danish Prakash <danish.prakash@suse.com>
- Disable restricting builds only for tier1 platforms
  i.e. only for x86_64 and aarch64 and enable for all.
* Mon Jul  3 2023 danish.prakash@suse.com
- Update to version 1.7.0:
  * release v1.7.0
  * Update release notes for v1.7.0
  * fix(deps): update rust crate tokio to 1.29.0
  * fix(deps): update rust crate clap to 4.3.8
  * fix(deps): update rust crate clap to 4.3.5
  * run cargo update
  * [CI:BUILD] Packit: add Fedora downstream tasks
  * fix(deps): update rust crate clap to 4.3.4
  * chore(deps): update dependency containers/automation_images to v20230614
  * fix(deps): update rust crate clap to 4.3.3
  * fix(deps): update rust crate log to 0.4.19
  * fix(deps): update rust crate clap to 4.3.2
  * fix(deps): update rust crate clap to 4.3.1
  * cirrus: remove verify_vendor task
  * chore(deps): update dependency containers/automation_images to v20230601
  * fix(deps): update rust crate trust-dns-server to 0.22.1
  * chore(deps): update rust crate chrono to 0.4.26
  * fix(deps): update rust crate tokio to 1.28.2
  * fix(deps): update rust crate log to 0.4.18
  * chore(deps): update rust crate chrono to 0.4.25
  * fix(deps): update rust crate clap to 4.3.0
  * chore(deps): update dependency containers/automation_images to v20230517
  * fix(deps): update rust crate tokio to 1.28.1
  * chore(deps): update dependency containers/automation_images to v20230426
  * fix(deps): update rust crate clap to 4.2.7
  * fix(deps): update rust crate anyhow to 1.0.71
  * fix typo in makefile
  * fix(deps): update rust crate tokio to 1.28.0
  * fix(deps): update rust crate clap to 4.2.5
  * fix(deps): update rust crate syslog to ^6.1.0
  * fix(deps): update rust crate clap to 4.2.4
  * fix(deps): update rust crate clap to 4.2.3
  * fix(deps): update rust crate clap to v4
  * chore(deps): update dependency containers/automation_images to v20230405
  * bump to v1.7.0-dev
* Wed Apr 12 2023 danish.prakash@suse.com
- Update to version 1.6.0:
  * v1.6.0 release
  * Update release notes for v1.6.0
  * fix(deps): update rust crate tokio to 1.27.0
  * use lower TTL for contianer entries
  * fix(deps): update rust crate syslog to ^6.0.1
  * fix(deps): update rust crate futures-util to 0.3.28
  * chore(deps): update dependency containers/automation_images to v20230330
  * Disable Dependabot in favor of Renovate
  * chore(deps): update dependency containers/automation_images to v20230320
  * build(deps): bump futures-util from 0.3.26 to 0.3.27
  * [CI:BUILD] Packit: trigger builds on commit to main branch
  * build(deps): bump anyhow from 1.0.68 to 1.0.70
  * fix lint issue with new rust version 1.68
  * Cirrus: Update to newer CI VM images
  * build(deps): bump chrono from 0.4.23 to 0.4.24
  * build(deps): bump libc from 0.2.139 to 0.2.140
  * build(deps): bump async-broadcast from 0.5.0 to 0.5.1
  * build(deps): bump signal-hook from 0.3.14 to 0.3.15
  * build(deps): bump futures-util from 0.3.25 to 0.3.26
  * build(deps): bump tokio from 1.25.0 to 1.26.0
  * [CI:DOCS] Clarify packit related comments
  * [CI:BUILD] Packit: initial enablement
  * Allow custom cargo binary path
  * Switch to explicit platform list for `cargo vendor-filterer`
  * bump to v1.6.0-dev
  * Add renovate.json5
  * Cirrus: Groom rust cache before updating
* Fri Mar 17 2023 Danish Prakash <danish.prakash@suse.com>
- Fix libexecdir issue on Leap and SLE
* Tue Feb 14 2023 Danish Prakash <danish.prakash@suse.com>
- First version of aardvark-dns
